"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseGroupFilter = void 0;
const ramda_1 = __importDefault(require("ramda"));
class BaseGroupFilter {
    constructor(filter) {
        this.values = filter.values;
        this.operator = filter.operator;
        this.measure = filter.measure;
        this.dimension = filter.dimension;
    }
    isDateOperator() {
        return false;
    }
    conditionSql(column) {
        return `(\n${this.values.map(f => f.conditionSql(column)).join(` ${this.operator.toUpperCase()} `)}\n)`;
    }
    filterToWhere() {
        const r = this.values.map(f => {
            const sql = f.filterToWhere();
            if (!sql) {
                return null;
            }
            return `(${sql})`;
        }).filter(ramda_1.default.identity).join(` ${this.operator.toUpperCase()} `);
        if (!r.length) {
            return null;
        }
        return r;
    }
    filterParams() {
        return this.values.map(f => f.filterParams());
    }
    getMembers() {
        return this.values.map(f => {
            if (f.getMembers) {
                return f.getMembers();
            }
            return f;
        });
    }
}
exports.BaseGroupFilter = BaseGroupFilter;
//# sourceMappingURL=BaseGroupFilter.js.map